package message

// Timestamp as used in internet mail messages.
const RFC5322Z = "2 Jan 2006 15:04:05 -0700"
